// Package response ...
//
// Description : response ...
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 2022-06-25 20:52
package response

import (
	"net/http"
	"time"

	"git.zhangdeman.cn/zhangdeman/exception"
	"git.zhangdeman.cn/zhangdeman/gin/define"
	"github.com/gin-gonic/gin"
)

// Success 成功的响应
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 22:37 2022/6/25
func Success(ctx *gin.Context, data map[string]interface{}) {
	successException := exception.NewSuccess(data)
	Send(ctx, successException.GetCode(), successException.GetHttpCode(), successException.GetData())
}

// Send 基础的发送数据
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 22:40 2022/6/25
func Send(ctx *gin.Context, code interface{}, httpCode int, data map[string]interface{}) {
	e := exception.New(code, httpCode, data)
	responseData := map[string]interface{}{
		define.ResponseCodeField:      e.GetCode(),
		define.ResponseMessageField:   e.GetMessage(),
		define.ResponseTraceIDField:   ctx.GetString(define.TraceIDField),
		define.ResponseRequestIDField: ctx.GetString(define.RequestIDField),
		define.ResponseDataField:      data,
		define.HandleRequestCostField: (time.Now().UnixNano() - ctx.GetInt64(define.StartRequestTimeField)) / 1e9,
	}
	responseException := exception.New(e.GetCode(), e.GetHttpCode(), responseData)
	ctx.JSON(responseException.GetHttpCode(), responseException.GetData())
}

// SendWithStatusOK ...
//
// Author : go_developer@163.com<白茶清欢>
//
// Date : 22:41 2022/6/25
func SendWithStatusOK(ctx *gin.Context, code interface{}, data map[string]interface{}) {
	Send(ctx, code, http.StatusOK, data)
}
